package org.jcomet.core;

import java.io.File;
import java.io.IOException;
import java.util.Timer;
import java.util.TimerTask;

/**
 * Monitors a file and notifys you when it has changed
 * @author Amir Shevat
 *
 */
public class FileMonitor {
    private static Timer timer= new Timer(true);
    private FileMonitorTask task;
   
    /**
     * Monitors a file and notifys you when it has changed
     * @param file the file to be monitored 
     * @param listener the listener to be notified
     * @param period the interval in which to check the file
     */
    public FileMonitor(File file, FileChangeListener listener,long period ) { 

    	task = new FileMonitorTask(listener, file);
    	timer.schedule(task, period, period);
    }
    
    /**
     * stops the monitoring
     */
    public void stop(){
    	task.cancel();
    }  
    
    protected void fireFileChangeEvent(FileChangeListener listener, File file) throws IOException {
    	listener.fileChanged(file);
    }

    class FileMonitorTask extends TimerTask {
        FileChangeListener listener;
        long lastChanged;
        File monitoredFile;

        FileMonitorTask(FileChangeListener listener, File file){
        	
        	this.lastChanged = 0;
        	this.listener = listener;
	    

	    monitoredFile = file;
	    this.lastChanged = monitoredFile.lastModified();
	}

        public void run() {
		    long lastModified = monitoredFile.lastModified();
		    if (lastModified != this.lastChanged) {
		        this.lastChanged = lastModified;
			try {
				fireFileChangeEvent(this.listener, monitoredFile);
			} catch (IOException e) {
				e.printStackTrace();
			}
	    }
	}
    }
}
